#
# spec file for package kubectl-browse-pvc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name kubectl-browse_pvc

Name:           kubectl-browse-pvc
Version:        1.2.0
Release:        1.1
Summary:        Kubectl plugin for browsing PVCs on the command line
License:        MIT
URL:            https://github.com/clbx/kubectl-browse-pvc
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go1.22

%description
I constantly found myself spinning up dummy pods to exec into them so I could
browse a PVC, this takes a few steps out of creating dummy pods to check out
the contents of a PVC.

Usage

`kubectl browse-pvc -n <namespace> <pvc-name>`

On an unbound PVC. The tool spins up a pod that mounts the PVC and then execs
into it allowing you to modify the contents of the PVC. The Job finishes and
cleans up the pod when you disconnect.

%prep
%autosetup -a 1 -p 1
mv vendor ./src/

%build
%ifarch s390x i586 riscv64
CGO_ENABLED=1 \
%else
CGO_ENABLED=0 \
%endif
cd src/
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X main.Version=v%{version}" \
   -o ../bin/%{executable_name} .

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

%check

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%changelog
* Thu Feb 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.2.0:
  * allow mounting to bound pods
  * Bump golang.org/x/net from 0.23.0 to 0.33.0 in /src
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.1.0:
  * add ability to execute commands
  * add hostname to ps1
  * forgot to hit save
  * pull namespace from current context
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.0.8:
  * create builds for x86 and arm, linux and mac
  * fix x2
  * fix path
  * trying to get windows build, move into src
  * remove old files
  * add x86 macos and windows builds
* Mon Dec 16 2024 Andreas Schwab <schwab@suse.de>
- Enable cgo on riscv64
* Mon Sep 16 2024 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Add ifarch with  CGO_ENABLED=1 for fixing failed builds
* Thu Jul 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.0.7:
  * deps
  * test with common build job?
  * unconsolidate ci
  * Revert "consolidate ci"
  * Revert "remove old files"
  * consolidate ci
  * remove old files
  * fix names, fix command to work on ubi
* Sat Jul 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.0.6:
  * add version to release
  * try adding commit to version for devel builds
  * remove comments
  * use less utilities
  * inject script instead of baking into image
  * remove integration tests
  * fix release pipeline
  * use a short sha instead
  * remove from directory
  * rename image, update ci
* Tue May 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package kubectl-browse-pvc: Kubectl plugin for browsing PVCs
  on the command line
